//$Id: dialog-res.cc,v 1.24 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "dialog-res.h"
#include "dialog-win.h"

using namespace Guikachu;

Resources::Dialog::Dialog (ResourceManager   *manager,
			   const std::string &id):
    Resource (manager, id),
    gui (0),
    title (changed, ""),
    text (changed, ""),
    dialog_type (changed, TYPE_INFORMATION),
    buttons (changed),
    default_button (changed, 0),
    help_id (changed, manager, "")
{
}

Resources::Dialog::~Dialog ()
{
    delete gui;
}

void Resources::Dialog::show_ui ()
{
    if (!gui)
	gui = new GUI::DialogWindow (this);

    gui->show ();
}
